@@ -43,6 +43,10 @@ pub fn init(origin_storage_dir: Option<PathBuf>) -> Extension {
     .build()
 }
 
+pub fn get_declaration() -> PathBuf {
+  PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("lib.deno_webstorage.d.ts")
+}
+
 struct LocalStorage(Connection);
 struct SessionStorage(Connection);
 
